==> aws-cdk.aws-msk-alpha-2.0.0a2.tar.gz: package/lib/cluster-version.d.ts <==
/**
 * (experimental) Kafka cluster version.
 *
 * @experimental
 */
export declare class KafkaVersion {
    readonly version: string;
    /**
     * (experimental) Kafka version 1.1.1.
     *
     * @experimental
     */
    static readonly V1_1_1: KafkaVersion;
    /**
     * (experimental) Kafka version 2.2.1.
     *
     * @experimental
     */
    static readonly V2_2_1: KafkaVersion;
    /**
     * (experimental) Kafka version 2.3.1.
     *
     * @experimental
     */
    static readonly V2_3_1: KafkaVersion;
    /**
     * (experimental) Kafka version 2.4.1.
     *
     * @experimental
     */
    static readonly V2_4_1_1: KafkaVersion;
    /**
     * (experimental) Kafka version 2.5.1.
     *
     * @experimental
     */
    static readonly V2_5_1: KafkaVersion;
    /**
     * (experimental) Kafka version 2.6.0.
     *
     * @experimental
     */
    static readonly V2_6_0: KafkaVersion;
    /**
     * (experimental) Kafka version 2.6.1.
     *
     * @experimental
     */
    static readonly V2_6_1: KafkaVersion;
    /**
     * (experimental) Kafka version 2.7.0.
     *
     * @experimental
     */
    static readonly V2_7_0: KafkaVersion;
    /**
     * (experimental) Kafka version 2.8.0.
     *
     * @experimental
     */
    static readonly V2_8_0: KafkaVersion;
    /**
     * (experimental) Kafka version 2.8.1.
     *
     * @experimental
     */
    static readonly V2_8_1: KafkaVersion;
    /**
     * (experimental) Custom cluster version.
     *
     * @param version custom version number.
     * @experimental
     */
    static of(version: string): KafkaVersion;
    /**
     *
     * @param version cluster version number
     */
    private constructor();
}

==> aws-cdk.aws-msk-alpha-2.4.0a0.tar.gz: package/lib/cluster-version.d.ts <==
/**
 * (experimental) Kafka cluster version.
 *
 * @experimental
 */
export declare class KafkaVersion {
    readonly version: string;
    /**
     * (experimental) Kafka version 1.1.1.
     *
     * @experimental
     */
    static readonly V1_1_1: KafkaVersion;
    /**
     * (experimental) Kafka version 2.2.1.
     *
     * @experimental
     */
    static readonly V2_2_1: KafkaVersion;
    /**
     * (experimental) Kafka version 2.3.1.
     *
     * @experimental
     */
    static readonly V2_3_1: KafkaVersion;
    /**
     * (experimental) Kafka version 2.4.1.
     *
     * @experimental
     */
    static readonly V2_4_1_1: KafkaVersion;
    /**
     * (experimental) Kafka version 2.5.1.
     *
     * @experimental
     */
    static readonly V2_5_1: KafkaVersion;
    /**
     * (experimental) Kafka version 2.6.0.
     *
     * @experimental
     */
    static readonly V2_6_0: KafkaVersion;
    /**
     * (experimental) Kafka version 2.6.1.
     *
     * @experimental
     */
    static readonly V2_6_1: KafkaVersion;
    /**
     * (experimental) Kafka version 2.6.2.
     *
     * @experimental
     */
    static readonly V2_6_2: KafkaVersion;
    /**
     * (experimental) Kafka version 2.6.3.
     *
     * @experimental
     */
    static readonly V2_6_3: KafkaVersion;
    /**
     * (experimental) Kafka version 2.7.0.
     *
     * @experimental
     */
    static readonly V2_7_0: KafkaVersion;
    /**
     * (experimental) Kafka version 2.7.1.
     *
     * @experimental
     */
    static readonly V2_7_1: KafkaVersion;
    /**
     * (experimental) Kafka version 2.7.2.
     *
     * @experimental
     */
    static readonly V2_7_2: KafkaVersion;
    /**
     * (experimental) Kafka version 2.8.0.
     *
     * @experimental
     */
    static readonly V2_8_0: KafkaVersion;
    /**
     * (experimental) Kafka version 2.8.1.
     *
     * @experimental
     */
    static readonly V2_8_1: KafkaVersion;
    /**
     * (experimental) Custom cluster version.
     *
     * @param version custom version number.
     * @experimental
     */
    static of(version: string): KafkaVersion;
    /**
     *
     * @param version cluster version number
     */
    private constructor();
}
